#!/usr/bin/env python
import math
"""List of all constants available

Call function variables() to learn more.
"""
pi = math.pi
eulersnum= math.e
eulersmasch = 0.577215664901532860606512
golden_ratio = 1.6180339887498948420
light_speed = 299792458
avogadro = 6.02214076e23
boltzmann = 1.380649e-23
gas_constant = 8.314462618
luminous_efficacy= 683
atmosphere=101325
speed_of_light = 299792458
def variables():
    print('''
earth.gravity = 9.807 m/s^2
moon.gravity = 1.62 m/s^2
mars.gravity = 3.711 m/s^2
jupiter.gravity = 24.79 m/s^2
neptune.gravity = 11.15 m/s^2
mercury.gravity = 3.7 m/s^2
saturn.gravity = 10.44 m/s^2
uranus.gravity = 8.87 m/s^2
venus.gravity = 8.87 m/s^2
pluto.gravity = 0.62 m/s^2

earth.mass =  5.98 * 10^24 kg
earth.radius = 6371 km
earth.surface_area = 510.1 km^2

moon.mass = 7.34767309e22 kg
moon.radius = 1737.1 km
moon.surface_area = 3.793e7 km^2

mars.mass = 6.4171e23 kg
mars.radius = 3389.5 km
mars.surface_area = 114.8 km^2

jupiter.mass = 1.898e27 kg
jupiter.radius = 69911 km
jupiter.surface_area = 61420 km^2

neptune.mass = 1.024e26 kg
neptune.radius = 24622 km
neptune.surface_area = 7618 km^2

mercury.mass = 3.285e23 kg
mercury.radius = 2439.7 km
mercury.surface_area = 74.8 km^2

saturn.mass = 5.683e26 kg
saturn.radius = 58232 km
saturn.surface_area = 42700 km^2

uranus.mass = 8.681e25 kg
uranus.radius = 25362 km
uranus.surface_area = 8083 km^2

venus.mass = 4.867e24 kg
venus.radius = 6051.8 km
venus.surface_area = 460.2 km^2

pluto.mass = 1.30900e22 kg
pluto.radius = 1188.3 km
pluto.surface_area = 16647940 km^2

earth.sun_distance = 149,597,870 km
mars.sun_distance = 227,940,000 km
mercury.sun_distance = 57,900,000 km
venus.sun_distance = 108,200,000 km
jupiter.sun_distance = 778,300,000 km
neptune.sun_distance = 4,497,100,000 km
saturn.sun_distance = 1,427,000,000 km
uranus.sun_distance = 2,871,000,000 km
pluto.sun_distance = 5,913,000,000 km

speed_of_light = 299792458 m/s
pi = 3.141592653589793
eulersnum = 2.7182818284590452353602874713527
eulersmasch = 0.577215664901532860606512
golden_ratio = 1.6180339887498948420
light_speed = 299792458 m/s
boltzmann = 1.380649e−23 J/K
gas_constant = 8.314462618 J/mol K
luminous_efficacy = 683 lm/W
atmosphere = 101325 Pa
avogadros_num = 6.02214086 * 10^23 mol^-1

mass in KG
radius in KM
surface area in km^2
gravity in m/s^2
''')



#!/usr/bin/env python
from .equations import *
from .constants import *
from .planets import *
from .chemistry import *
import logging
logging.getLogger(__name__).info("Made using Tiquations 1.2")
__author__="Tinos Psomadakis"
__copyright__="Copyright (c) 2018 Tinos Psomadakis"
__credits__ = ["Creme", "Sir Eraz", "Paul Kienzle"]
__version__ = "1.2"
__maintainer__ = "Tinos Psomadakis"
__email__ = "tinosps@gmail.com"
__status__ = "Release"
